# Qimchi
## 🚧 Under Construction 🚧
Plotly based data visualization tool for xarray data. Optimized to work with the [qcutils](https://gitlab.com/squad-lab/qcutils) package.

## Installation
This pip package has only been tested with `python>=3.11`. Separate `venv` testing environment is suggested while the package is in production. 
```
pip install git+ssh://git@gitlab.com/squad-lab/qimchi.git
```
This should install the app, and you should be ready to go.

## Run Qimchi
Running qimchi is easy, after installing it in a suitable environment:
```python
py -m qimchi
```
